@@ -18,7 +18,7 @@
 // along with this program ; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 //
-// $Id: RTIG.cc,v 3.36 2008/03/07 16:10:06 rousse Exp $
+// $Id: RTIG.cc,v 3.39 2008/04/08 14:18:17 rousse Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -142,7 +142,7 @@ RTIG::chooseProcessingMethod(Socket *link, NetworkMessage *msg)
         D.Out(pdTrace, "Federate no %u leaves federation no %u .",
               msg->federate, msg->federation);
         auditServer.setLevel(9);
-        processResignFederation(msg->federation, msg->federate);
+        processResignFederation(link,msg->federation, msg->federate);
         break ;
 
       case NetworkMessage::REGISTER_FEDERATION_SYNCHRONIZATION_POINT:
@@ -389,6 +389,7 @@ RTIG::closeConnection(Socket *link, bool emergency)
     Handle federation ;
     FederateHandle federate ;
 
+    G.Out(pdGendoc,"enter RTIG::closeConnection");
     try {
         socketServer.close(link->returnSocket(), federation, federate);
     }
@@ -401,6 +402,8 @@ RTIG::closeConnection(Socket *link, bool emergency)
         federations.killFederate(federation, federate);
         D.Out(pdExcept, "Federate(%u, %u)Killed... ", federation, federate);
     }
+
+    G.Out(pdGendoc,"exit  RTIG::closeConnection");
 }
 
 // ----------------------------------------------------------------------------
@@ -963,6 +966,7 @@ RTIG::processIncomingMessage(Socket *link)
     if (link == NULL) return link ;
 
     if (rep.exception != e_NO_EXCEPTION) {
+        G.Out(pdGendoc,"            processIncomingMessage ===> write on exception to RTIA");
         rep.write(link);
         D.Out(pdExcept,
               "RTIG catched exception %d and sent it back to federate %d.",
@@ -987,4 +991,4 @@ if (sig == SIGINT) terminate = true ;
 
 }} // namespace certi/rtig
 
-// $Id: RTIG.cc,v 3.36 2008/03/07 16:10:06 rousse Exp $
+// $Id: RTIG.cc,v 3.39 2008/04/08 14:18:17 rousse Exp $
